##########################################################################################
## Hiram Sarabia, MS                                                                    ##
## Environmental Scientist                                                              ##
## San Diego Water Board                                                                ##
## September 2023                                                                          ##
##                                                                                      ##
## Goal: Estimate population parameters and sample statistics based                     ##
## on contemporary sediment chemistry data for San Diego Bay                            ##                                        ##
##########################################################################################
#Install package on list if missing in installed.packages(): https://stackoverflow.com/questions/4090169/elegant-way-to-check-for-missing-packages-and-install-them
list.of.packages <- c("tidyverse", "gsubfn","boot","NADA2","vctrs")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)
#install.packages("vctrs") need newer version of vctrs
#Load needed packages
library(boot)
library(NADA2)
library(tidyverse)

closeAllConnections() 

###########################
### UNCENSORED DATASETS ###
###########################

###########################################
### Cadmium - BOOTSTRAP - LINES: 25-185 ###
###########################################

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_Cd_57bRandomSites <- read.csv("SDBay_Cd_57bRandomSites.csv", stringsAsFactors = F)
SDBay_Cd_49bRandomSites <- read.csv("SDBay_Cd_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

#############
## Cadmium ##
#############

#SDBay_Cd_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Cd_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Cd_57bRandomSites.txt"))
print("SDBay_Cd_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#SDBay_Cd_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Cd_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Cd_49bRandomSites.txt"))
print("SDBay_Cd_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

################################
### Copper - LINES: 171-316  ###
################################

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_Cu_57bRandomSites <- read.csv("SDBay_Cu_57bRandomSites.csv", stringsAsFactors = F)
SDBay_Cu_49bRandomSites <- read.csv("SDBay_Cu_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

############
## Copper ##
############

#SDBay_Cu_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Cu_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Cu_57bRandomSites.txt"))
print("SDBay_Cu_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#SDBay_Cu_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Cu_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Cu_49bRandomSites.txt"))
print("SDBay_Cu_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

###########################################
### Mercury - BOOTSTRAP  LINES: 316-464 ###
###########################################

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_Hg_57bRandomSites <- read.csv("SDBay_Hg_57bRandomSites.csv", stringsAsFactors = F)
SDBay_Hg_49bRandomSites <- read.csv("SDBay_Hg_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

#############
## Mercury ##
#############

#SDBay_Hg_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Hg_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Hg_57bRandomSites.txt"))
print("SDBay_Hg_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#SDBay_Hg_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Hg_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Hg_49bRandomSites.txt"))
print("SDBay_Hg_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()


########################################
### Lead - BOOTSTRAP  LINES: 466-611 ###
########################################

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_Pb_57bRandomSites <- read.csv("SDBay_Pb_57bRandomSites.csv", stringsAsFactors = F)
SDBay_Pb_49bRandomSites <- read.csv("SDBay_Pb_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

########## 
## Lead ##
##########

#SDBay_Pb_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Pb_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Pb_57bRandomSites.txt"))
print("SDBay_Pb_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#SDBay_Pb_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Pb_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Pb_49bRandomSites.txt"))
print("SDBay_Pb_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

########################################
### Zinc - BOOTSTRAP  LINES: 615-760 ###
########################################

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_Zn_57bRandomSites <- read.csv("SDBay_Zn_57bRandomSites.csv", stringsAsFactors = F)
SDBay_Zn_49bRandomSites <- read.csv("SDBay_Zn_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

########## 
## Zinc ##
##########

#SDBay_Zn_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Zn_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Zn_57bRandomSites.txt"))
print("SDBay_Zn_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#SDBay_Zn_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_Zn_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_Zn_49bRandomSites.txt"))
print("SDBay_Zn_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

############################################
### TPAH - BOOTSTRAP  LINES: 765-910 ###
############################################

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_TPAH_57bRandomSites <- read.csv("SDBay_TPAH_57bRandomSites.csv", stringsAsFactors = F)
SDBay_TPAH_49bRandomSites <- read.csv("SDBay_TPAH_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

########## 
## TPAH ##
##########

#SDBay_TPAH_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_TPAH_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_TPAH_57bRandomSites.txt"))
print("SDBay_TPAH_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#SDBay_TPAH_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_TPAH_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_TPAH_49bRandomSites.txt"))
print("SDBay_TPAH_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#####################################
### TPCB - BOOTSTRAP  LINES: 915- ###
#####################################

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_TPCB_49bRandomSites <- read.csv("SDBay_TPCB_49bRandomSites.csv", stringsAsFactors = F)
#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

########## 
## TPCB ##
##########

#SDBay_TPCB_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_TPCB_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_TPCB_49bRandomSites.txt"))
print("SDBay_TPCB_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci 
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

###############################################################
######################   CENSORED DATASETS - LINES: 915-    ###
###############################################################

#################
##  BOOTSTRAP ###
#################

#Substitution by zero of non-detects is the current regulatory practice recommended by 
#Bay et al. (2021) for calculation of total sum of congeners (i.e., total PAHs, total PCBs, etc.). 
#Extending that same practice to the calculation of summary statistics for a collection of sites,
#where each with site has a unique total PAH, total PCB result, then all non-detect values for 
#total PAHs and total PCBs are substituted by zero below.
#NOTE: The inclusion of this practice is only for comparison purposes and not as a recommendation.

###################
###   DIELDRIN  ###
###################
#100% Censored all datasets (9/14/23)
#No percentiles can be calculated 

###############
###   TCHL  ###
###############
#94.7% SDBay_TCHL_ag_57bRandomSites (54 of 57)
#93.9% SDBay_TCHL_ag_49bRandomSites (46 of 49)
#Censoring is to high to calculate any percentiles of interest 
#(i.e., c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95))

###########################################################################
###   TDDT - SDBay_TDDT_58aRandomSites - Bootstrap  LINES: 945 - 1103   ###
###########################################################################
#80.7% SDBay_TDDT_57bRandomSites (46 of 57)
#79.6% SDBay_TDDT_49bRandomSites (39 of 49)
#Bootstrap used to calculate 95th percentile

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')

#Load data
SDBay_TDDT_57bRandomSites <- read.csv("SDBay_TDDT_57bRandomSites.csv", stringsAsFactors = F)
SDBay_TDDT_49bRandomSites <- read.csv("SDBay_TDDT_49bRandomSites.csv", stringsAsFactors = F)

#Replace non-detects with zero
#library(dplyr)
#alternate
#Dplyr::if_else is a vectorized if-else that allows handling of missing values
SDBay_TDDT_57bRandomSites$Result <- ifelse(SDBay_TDDT_57bRandomSites$Censored == T, 0, SDBay_TDDT_57bRandomSites$Result)
SDBay_TDDT_49bRandomSites$Result <- ifelse(SDBay_TDDT_49bRandomSites$Censored == T, 0, SDBay_TDDT_49bRandomSites$Result)

#SAVE Datasets with NDs substituted by zero
write.csv(SDBay_TDDT_57bRandomSites, paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TDDT_57bRandomSites_SBZ.csv"))
write.csv(SDBay_TDDT_49bRandomSites, paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TDDT_49bRandomSites_SBZ.csv"))

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

#SDBay_TDDT_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_TDDT_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_TDDT_57bRandomSites_SubstitutionbyZero.txt"))
print("SDBay_TDDT_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
# bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
# bo.median
# bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
# bo.95ci 
# bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
# bo.mean
# bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
# bo.95ci
sink()


#SDBay_TDDT_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_TDDT_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_TDDT_49bRandomSites_SubstitutionbyZero.txt"))
print("SDBay_TDDT_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
# bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
# bo.median
# bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
# bo.95ci 
# bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
# bo.mean
# bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
# bo.95ci
sink()

#############
############
############

###########################################################################
###   TPCB - SDBay_PCB_58aRandomSites - Bootstrap  LINES: 1111 - 1269   ###
###########################################################################
#5.3% SDBay_TPCB_57bRandomSites (3 of 57)
#6.1% SDBay_TPCB_49bRandomSites (3 of 49)
#Bootstrap used to calculate 95th percentile

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')

#Load data
SDBay_TPCB_57bRandomSites <- read.csv("SDBay_TPCB_57bRandomSites.csv", stringsAsFactors = F)
SDBay_TPCB_49bRandomSites <- read.csv("SDBay_TPCB_49bRandomSites.csv", stringsAsFactors = F)

#Replace non-detects with zero
#library(dplyr)
#alternate
#Dplyr::if_else is a vectorized if-else that allows handling of missing values
SDBay_TPCB_57bRandomSites$Result <- ifelse(SDBay_TPCB_57bRandomSites$Censored == T, 0, SDBay_TPCB_57bRandomSites$Result)
SDBay_TPCB_49bRandomSites$Result <- ifelse(SDBay_TPCB_49bRandomSites$Censored == T, 0, SDBay_TPCB_49bRandomSites$Result)

#SAVE Datasets with NDs substituted by zero
write.csv(SDBay_TPCB_57bRandomSites, paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TPCB_57bRandomSites_SBZ.csv"))
write.csv(SDBay_TPCB_49bRandomSites, paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TPCB_49bRandomSites_SBZ.csv"))

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')


#SDBay_TPCB_57bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_TPCB_57bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_TPCB_57bRandomSites_SubstitutionbyZero.txt"))
print("SDBay_TPCB_57bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#SDBay_TPCB_49bRandomSites
library(boot)
set.seed(2375)
data <- data.frame(SDBay_TPCB_49bRandomSites)
#View(data)
meanfun <- function(data, i){
  d <- data[i, ]
  return(mean(d))   
}
medianfun <- function(data, i){
  d <- data[i, ]
  return(median(d))   
}
quantfun <- function(data, i){
  d <- data[i, ]
  return(quantile(d, c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95)))   
}

sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "_SDBay_TPCB_49bRandomSites_SubstitutionbyZero.txt"))
print("SDBay_TPCB_49bRandomSites")
bo.quant  <- boot(data[, "Result", drop = FALSE], statistic=quantfun, R=10000)
bo.quant
bo.median <- boot(data[, "Result", drop = FALSE], statistic=medianfun, R=10000)
bo.median
bo.95ci <- boot.ci(bo.median, conf=0.95, type="bca")
bo.95ci
bo.mean <- boot(data[, "Result", drop = FALSE], statistic=meanfun, R=10000)
bo.mean
bo.95ci <- boot.ci(bo.mean, conf=0.95, type="bca")
bo.95ci
sink()

#############################################################
#####################  KAPLAN-MEYER #########################
#############################################################

#NADA 2 - Dr. Helsel's recommendation

#####################
###   DIELDRIN KM ###
#####################
#100% Censored all datasets

##################
###   TCHL KM  ###
##################
#94.7% SDBay_TCHL_ag_57bRandomSites (54 of 57)
#93.9% SDBay_TCHL_ag_49bRandomSites (46 of 49)
#Censoring is to high to calculate any percentiles of interest 
#(i.e., c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.95))

###########################################################################
###   TDDT - SDBay_TDDT_58aRandomSites - KM LINES: 1294-1347   ###
###########################################################################
#80.7% SDBay_TDDT_57bRandomSites (46 of 57)
#79.6% SDBay_TDDT_49bRandomSites (39 of 49)

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_TDDT_57bRandomSites <- read.csv("SDBay_TDDT_57bRandomSites.csv", stringsAsFactors = F)
SDBay_TDDT_49bRandomSites <- read.csv("SDBay_TDDT_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

library(NADA2)
dataTDDT57b <- data.frame(SDBay_TDDT_57bRandomSites)
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TDDT_57bRandomSites_KM.txt"))
#sink("SDBay_TDDT_57bRandomSites_KM.txt")
print("SDBay_TDDT_57bRandomSites")
tddtkm = cfit(dataTDDT57b$Result,dataTDDT57b$Censored, qtls = c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,.90,.95))
tddtkm
sink()

library(NADA2)
dataTDDT49b <- data.frame(SDBay_TDDT_49bRandomSites)
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TDDT_49bRandomSites_KM.txt"))
#sink("SDBay_TDDT_49bRandomSites_KM.txt")
print("SDBay_TDDT_49bRandomSites")
tddtkm = cfit(dataTDDT49b$Result,dataTDDT49b$Censored, qtls = c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,.90,.95))
tddtkm
sink()

###########
###########
##########

###########################################################################
###   TPCB - SDBay_TPCB_58aRandomSites - KM LINES: 1353- 1413           ###
###########################################################################
#5.3% SDBay_TPCB_57bRandomSites (3 of 57)
#6.1% SDBay_TPCB_49bRandomSites (3 of 49)
#Bootstrap used to calculate 95th percentile

#Set working directory
setwd('C:\\R\\SDBayBackground\\Input\\Dataset')
#Load data
SDBay_TPCB_57bRandomSites <- read.csv("SDBay_TPCB_57bRandomSites.csv", stringsAsFactors = F)
SDBay_TPCB_49bRandomSites <- read.csv("SDBay_TPCB_49bRandomSites.csv", stringsAsFactors = F)

#Set output directory
setwd('C:\\R\\SDBayBackground\\Output')

library(NADA2)
dataTPCB57b <- data.frame(SDBay_TPCB_57bRandomSites)
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TPCB_57bRandomSites_KM.txt"))
#sink("SDBay_TPCB_57bRandomSites_KM.txt")
print("SDBay_TPCB_57bRandomSites")
TPCBkm = cfit(dataTPCB57b$Result,dataTPCB57b$Censored, qtls = c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,.90,.95))
TPCBkm
sink()

library(NADA2)
dataTPCB49b <- data.frame(SDBay_TPCB_49bRandomSites)
sink(paste0(format(Sys.time(), "%d-%b-%Y %H.%M"), "SDBay_TPCB_49bRandomSites_KM.txt"))
#sink("SDBay_TPCB_49bRandomSites_KM.txt")
print("SDBay_TPCB_49bRandomSites")
TPCBkm = cfit(dataTPCB49b$Result,dataTPCB49b$Censored, qtls = c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,.90,.95))
TPCBkm
sink()

###########
###########
##########

closeAllConnections() 
traceback()
sessionInfo()